@@ -17,7 +17,10 @@ def Dense(x, K, B, shp=None):
     y += B.reshape((1, -1))
     return y
 
-def MatMul(x, y): return np.matmul(x, y)
+def MatMul(x, y): 
+    if x.ndim == y.ndim == 2:
+        return np.matmul(x, y)
+    return np.dot(x, y)
 
 def Conv2d(x, K, B=None, group=1, strides=(1,1), dilations=(1,1), pads=(0,0,0,0)):
     if np is numpy: out = conv_for(x, K, group, pads, strides, dilations)
@@ -243,6 +246,8 @@ def Pad(x, pads, constant_value=0, mode='constant'):
     return np.pad(x, pads, **para)
 
 def Clip(x, min=0, max=1): 
+    minv, maxv = np.float16(min), np.float16(max)
+    if ep: return ep.evaluate('(((x-minv)*(x>minv))-(maxv-minv))*(x<maxv)+maxv')
     x = np.minimum(x, max, out=x)
     return np.maximum(x, min, out=x)
 
