@@ -109,11 +109,11 @@ def lstm(X, Y, w, r, b, ht, ct, dir=1):
         return np.divide(1, x, out=x)
 
     for t in list(range(X.shape[0]))[::dir]:
-        gates = np.matmul(X[t:t+1], w.T)
+        gates = np.matmul(X[t], w.T)
         gates += np.matmul(ht, r.T)
         gates += b[:b.shape[0]//2]
         gates += b[b.shape[0]//2:]
-        i, o, f, c = np.split(gates, 4, -1)
+        i, o, f, c = np.split(gates[None,:], 4, -1)
         sigmoid(i), sigmoid(f), tanh(c)
         f *= ct; i *= c; f += i; C = f
         o = sigmoid(o); o *= np.tanh(C)
